import React from 'react';
import Children from "./item";
import { getNormalDpi } from "../../utils/tools";
import "./index.less"; // 构建表头, 需要显示的数据

var headerBuilder = function headerBuilder(minColumn, maxColumn, columnWidth, stickyHeight, noFixed, fixedLeft) {
  var fixedLeftLen = fixedLeft.data.length;
  var columns = [];
  var left = [0];
  var pos = 0;

  for (var c = 1; c <= maxColumn; c++) {
    pos += columnWidth(c - 1);
    left.push(pos);
  }

  for (var i = minColumn; i <= maxColumn; i++) {
    columns.push({
      style: {
        height: stickyHeight,
        width: columnWidth(i),
        left: left[i]
      },
      data: noFixed.data[i],
      index: fixedLeftLen + i
    });
  }

  return columns;
};

var dStyle = function dStyle(width, height) {
  var params = {};
  if (width) params.width = width;
  if (height) params.height = height;
  return params;
};

var StickyHeader = function StickyHeader(_ref) {
  var rowKey = _ref.rowKey,
      rowSelection = _ref.rowSelection,
      stickyHeight = _ref.stickyHeight,
      stickyWidthLeft = _ref.stickyWidthLeft,
      stickyWidthRight = _ref.stickyWidthRight,
      columnInfo = _ref.columnInfo,
      dataSource = _ref.dataSource,
      minColumn = _ref.minColumn,
      maxColumn = _ref.maxColumn,
      columnWidth = _ref.columnWidth,
      changeColumns = _ref.changeColumns,
      changeTable = _ref.changeTable,
      moveLine = _ref.moveLine,
      excelBox = _ref.excelBox,
      salaryBox = _ref.salaryBox;
  var noFixed = columnInfo.noFixed,
      fixedLeft = columnInfo.fixedLeft,
      fixedRight = columnInfo.fixedRight,
      hierarchy = columnInfo.hierarchy;
  var centerColumns = headerBuilder(minColumn, maxColumn, columnWidth, stickyHeight, noFixed, fixedLeft);
  var isMerge = hierarchy === 2;
  return /*#__PURE__*/React.createElement("div", {
    className: "salaryExcelHeader"
  }, /*#__PURE__*/React.createElement("div", {
    className: "baseLeft",
    style: dStyle(stickyWidthLeft, stickyHeight)
  }, fixedLeft.data.map(function (v, index) {
    return /*#__PURE__*/React.createElement(Children, {
      key: index,
      index: index,
      style: dStyle(v.width),
      mainColumns: v,
      change: changeColumns,
      changeTable: changeTable,
      moveLine: moveLine,
      excelBox: excelBox,
      data: columnInfo,
      dataSource: dataSource,
      isMerge: isMerge,
      rowSelection: rowSelection,
      rowKey: rowKey,
      salaryBox: salaryBox,
      isFixCol: true
    });
  })), /*#__PURE__*/React.createElement("div", {
    className: "scrollable",
    style: dStyle(columnInfo.noFixed.res)
  }, centerColumns.map(function (_ref2, i) {
    var index = _ref2.index,
        data = _ref2.data,
        style = _ref2.style;
    return /*#__PURE__*/React.createElement("div", {
      className: "item",
      key: i,
      style: style
    }, /*#__PURE__*/React.createElement(Children, {
      key: data.dataIndex,
      index: index,
      style: dStyle(style.width),
      mainColumns: data,
      data: columnInfo,
      dataSource: dataSource,
      change: changeColumns,
      changeTable: changeTable,
      moveLine: moveLine,
      excelBox: excelBox,
      isMerge: isMerge,
      salaryBox: salaryBox
    }));
  })), /*#__PURE__*/React.createElement("div", {
    className: "baseRight",
    style: dStyle(stickyWidthRight - (getNormalDpi() ? 0 : 1), stickyHeight)
  }, fixedRight.data.map(function (v, index) {
    return /*#__PURE__*/React.createElement(Children, {
      key: index,
      index: index,
      style: dStyle(v.width),
      mainColumns: v,
      change: changeColumns,
      changeTable: changeTable,
      moveLine: moveLine,
      excelBox: excelBox,
      data: columnInfo,
      dataSource: dataSource,
      isMerge: isMerge,
      salaryBox: salaryBox,
      isFixCol: true
    });
  })));
};

export default StickyHeader;