import React, { isValidElement, useRef, useEffect } from 'react';
import { removeDom, getRefBounding, stopHoverFn, renderPopover } from "../Popover/common";
import "./index.less"; // 拖动的时候要阻止hover，

export default function Ellipsis(props) {
  var text = props.text,
      width = props.width,
      stopHover = props.stopHover,
      _props$canCopy = props.canCopy,
      canCopy = _props$canCopy === void 0 ? true : _props$canCopy;
  var curSpanRef = useRef();
  var timer = useRef();
  var pDiv = useRef(document.createElement('div'));
  useEffect(function () {
    return function () {
      hideDiv();
    };
  }, []);

  var hideDiv = function hideDiv() {
    window.inPopover = false;
    removeDom(pDiv.current);
  };

  var onMouseEnter = function onMouseEnter() {
    if (stopHoverFn(stopHover)) return;

    var _ref = curSpanRef.current || {},
        offsetWidth = _ref.offsetWidth,
        scrollWidth = _ref.scrollWidth;

    if (!offsetWidth || !scrollWidth) return;
    var info = getRefBounding(curSpanRef);

    if (offsetWidth < scrollWidth || width <= 22) {
      clearDelayTimer();
      renderPopover(info.top, info.left, info.width, text, pDiv, onPopMouseEnter, hideDiv);
    }
  }; // 鼠标移出，开一个定时器，100ms后关闭弹窗


  var onMouseLeave = function onMouseLeave() {
    if (stopHoverFn(stopHover)) return;

    if (canCopy) {
      window.inPopover = true;
      timer.current = window.setTimeout(function () {
        hideDiv();
        clearDelayTimer();
      }, 100);
    } else {
      hideDiv();
    }
  }; // 鼠标移入弹窗就取消上面那个100ms的定时器，弹窗也不会消失了


  var onPopMouseEnter = function onPopMouseEnter() {
    if (!canCopy) return;
    clearDelayTimer();
  };

  var clearDelayTimer = function clearDelayTimer() {
    if (timer.current) {
      clearTimeout(timer.current);
      timer.current = null;
    }
  };

  if ( /*#__PURE__*/isValidElement(text)) return text;
  return /*#__PURE__*/React.createElement("div", {
    ref: curSpanRef,
    onMouseEnter: onMouseEnter,
    onMouseLeave: onMouseLeave,
    className: "modal_ellipsis",
    style: {
      width: width
    }
  }, width <= 22 ? '...' : text);
}