function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

import { getRowKeys, getKey, getErrorDisabled } from "./utils/tools"; // true => 阻止渲染
// false => 可以渲染

export var areEqual = function areEqual(a, b) {
  // 使用renderModule-always， 允许一直需要渲染更新
  if (a.excelContext.reduxData.renderModule === 'always' || a.currentColumn.renderModule === 'always') {
    return false;
  } // console.log(a, b);


  var aRedux = a.excelContext.reduxData;
  var bRedux = b.excelContext.reduxData; // 自带默认参数的getRowKeys函数

  var getRowKey = function getRowKey(param) {
    return getRowKeys(a.rowKey, param);
  }; // 获取redux内的数据


  var getData = function getData() {
    var data = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
    var source = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    try {
      return data.reduce(function (m, n) {
        return m[n];
      }, source);
    } catch (_unused) {
      return {};
    }
  }; // 判断行，true => 变化|可以渲染   false => 不变化|不能渲染


  var validateRow = function validateRow(param) {
    var rowBase = param.rowBase,
        rowData = param.rowData;

    if (rowBase === 'rowIndex') {
      if (typeof rowData === 'string' && getKey(a.currentColumn) === rowData) {
        return true;
      }

      if (a.rowIndex === getData(rowData, aRedux) || b.rowIndex === getData(rowData, bRedux)) {
        return true;
      }
    }

    if (rowBase === 'rowKey') {
      if (getRowKey(a.data) === getRowKey(getData(rowData, aRedux)) || getRowKey(b.data) === getRowKey(getData(rowData, bRedux))) {
        return true;
      }
    }

    if (rowBase === 'rowIndexArea') {
      if (a.rowIndex >= getData(rowData[0], aRedux) && a.rowIndex <= getData(rowData[1], aRedux) || b.rowIndex >= getData(rowData[0], bRedux) && b.rowIndex <= getData(rowData[1], bRedux)) {
        return true;
      }
    }

    return false;
  }; // 判断列，true => 变化   false => 不变化


  var validateCol = function validateCol(param) {
    var colData = param.colData,
        colBase = param.colBase;

    if (colBase === 'colIndex') {
      if (a.colIndex === getData(colData, aRedux) || b.colIndex === getData(colData, bRedux)) {
        return true;
      }
    }

    if (colBase === 'dataIndex') {
      if (typeof colData === 'string' && getKey(a.currentColumn) === colData) {
        return true;
      }

      if (getKey(a.currentColumn) === getKey(getData(colData, aRedux)) || getKey(b.currentColumn) === getKey(getData(colData, bRedux))) {
        return true;
      }
    }

    if (colBase === 'colIndexArea') {
      if (a.colIndex >= getData(colBase[0], aRedux) && a.colIndex <= getData(colBase[1], aRedux) || b.colIndex >= getData(colBase[0], bRedux) && b.colIndex <= getData(colBase[1], bRedux)) {
        return true;
      }
    }

    return false;
  };

  var validateCell = function validateCell(param) {
    return validateRow(param) && validateCol(param);
  };

  var validate = function validate(param) {
    var type = param.type;
    if (type === 'row' && validateRow(param)) return true;
    if (type === 'col' && validateCol(param)) return true;
    return ['cell', 'area'].includes(type) && validateCell(param);
  }; // 1. 更新单元格 id 和 dataIndex
  // 2. 更新整行 id  getRowKeys 需要考虑data.mergeArr(表格合并单元格，因为children被折叠用掉了)
  // 3. 更新整列 dataIndex getKey 需要考虑data.children(表头合并单元格)
  // 使用redux里面的哪个值 去获取指定的单元格，
  // 获取单元格需要 getkey 和 getRowkeys 这两个方法，
  // 同时getkey方法还需要遍历data.children才可以
  // hover效果显示允许条件


  if (validate({
    type: 'row',
    rowData: ['mergeHoverIndex'],
    rowBase: 'rowIndex'
  })) {
    return false;
  } // 选中效果允许条件


  if (validate({
    type: 'cell',
    rowData: ['selectOneRow', 'data'],
    rowBase: 'rowKey',
    colData: ['selectOneRow'],
    colBase: 'dataIndex'
  })) {
    return false;
  }

  if (validate({
    type: 'cell',
    rowData: ['selectOneRow', 'rowIndex'],
    rowBase: 'rowIndex',
    colData: 'rowPrefixSp',
    colBase: 'dataIndex'
  })) {
    return false;
  }

  if (validate({
    type: 'area',
    rowData: [['copyDrags', 'rowIndex'], ['copyDrags', 'maxRowIndex']],
    rowBase: 'rowIndexArea',
    colData: ['copyCursor'],
    colBase: 'dataIndex'
  })) {
    return false;
  } // ============================== 内置条件 ==============================
  // 内置条件 = 折叠后的三角小图标变化;


  if (a.excelContext.reduxData.loadingExpandId !== b.excelContext.reduxData.loadingExpandId && (a.excelContext.reduxData.loadingExpandId === a.data[a.expandKey] || b.excelContext.reduxData.loadingExpandId === b.data[b.expandKey]) || a.data.expandStatus !== b.data.expandStatus) {
    return false;
  } // 内置条件 = 编辑条件下errors disabled 变化


  var curErrorData, nextErrorData;
  var aEditConfig = aRedux.editableConfig;

  if (aEditConfig.editable) {
    var _aEditConfig$errors = aEditConfig.errors,
        aErrors = _aEditConfig$errors === void 0 ? [] : _aEditConfig$errors,
        _aEditConfig$disabled = aEditConfig.disabled,
        aDisabled = _aEditConfig$disabled === void 0 ? [] : _aEditConfig$disabled;
    curErrorData = getErrorDisabled(aErrors.concat(aDisabled), getKey(a.currentColumn), getRowKey(a.data));
  }

  var bEditConfig = bRedux.editableConfig;

  if (bEditConfig.editable) {
    var _bEditConfig$errors = bEditConfig.errors,
        bErrors = _bEditConfig$errors === void 0 ? [] : _bEditConfig$errors,
        _bEditConfig$disabled = bEditConfig.disabled,
        bDisabled = _bEditConfig$disabled === void 0 ? [] : _bEditConfig$disabled;
    nextErrorData = getErrorDisabled(bErrors.concat(bDisabled), getKey(b.currentColumn), getRowKey(b.data));
  }

  if (curErrorData || nextErrorData) {
    return false;
  } // 内置条件 = 多选栏 一直可以刷新 （这里没写好，内部每个值都需要外部的值，无法限制渲染）


  if (getKey(a.currentColumn) === 'rowSelection') {
    return false;
  } // 内置条件 = 数据行选中变化


  if (b.rowSelection && b.rowSelection.selectedRowKeys.includes(getRowKey(a.data)) || a.rowSelection && a.rowSelection.selectedRowKeys.includes(getRowKey(a.data))) {
    return false;
  } // 内置条件 = 宽度变化


  if (a.currentColumn.width !== b.currentColumn.width) return false;

  if (a.rowKey && a.rowKey !== 'id') {
    if (getRowKey(a.data) !== getRowKey(b.data) || Object.keys(a.data).length !== Object.keys(b.data).length) {
      return false;
    } // 内置条件 = 数据变化


    return Object.is(a.data[getKey(a.currentColumn)], b.data[getKey(b.currentColumn)]);
  } else {
    var flag = true;

    if (Object.keys(a.data).length !== Object.keys(b.data).length) {
      flag = false;
    } else {
      Object.keys(a.data).forEach(function (key) {
        if (_typeof(a.data[key]) !== 'object') {
          if (a.data[key] !== b.data[key]) {
            flag = false;
          }
        }
      });
    }

    return flag;
  }
};